# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.ad_asset_pb2 import (
    AdImageAsset as google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset,
    AdMediaBundleAsset as google___ads___googleads___v6___common___ad_asset_pb2___AdMediaBundleAsset,
    AdTextAsset as google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset,
    AdVideoAsset as google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset,
)
from google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2 import (
    CallConversionReportingStateEnum as google___ads___googleads___v6___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum,
)
from google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2 import (
    DisplayAdFormatSettingEnum as google___ads___googleads___v6___enums___display_ad_format_setting_pb2___DisplayAdFormatSettingEnum,
)
from google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2 import (
    DisplayUploadProductTypeEnum as google___ads___googleads___v6___enums___display_upload_product_type_pb2___DisplayUploadProductTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2 import (
    LegacyAppInstallAdAppStoreEnum as google___ads___googleads___v6___enums___legacy_app_install_ad_app_store_pb2___LegacyAppInstallAdAppStoreEnum,
)
from google.ads.google_ads.v6.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v6___enums___mime_type_pb2___MimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TextAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    headline: typing___Text = ...
    description1: typing___Text = ...
    description2: typing___Text = ...
    def __init__(
        self,
        *,
        headline: typing___Optional[typing___Text] = None,
        description1: typing___Optional[typing___Text] = None,
        description2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description1", b"_description1"],
    ) -> typing_extensions___Literal["description1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description2", b"_description2"],
    ) -> typing_extensions___Literal["description2"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...

type___TextAdInfo = TextAdInfo

class ExpandedTextAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    headline_part1: typing___Text = ...
    headline_part2: typing___Text = ...
    headline_part3: typing___Text = ...
    description: typing___Text = ...
    description2: typing___Text = ...
    path1: typing___Text = ...
    path2: typing___Text = ...
    def __init__(
        self,
        *,
        headline_part1: typing___Optional[typing___Text] = None,
        headline_part2: typing___Optional[typing___Text] = None,
        headline_part3: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        description2: typing___Optional[typing___Text] = None,
        path1: typing___Optional[typing___Text] = None,
        path2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "_headline_part1",
            b"_headline_part1",
            "_headline_part2",
            b"_headline_part2",
            "_headline_part3",
            b"_headline_part3",
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "description",
            b"description",
            "description2",
            b"description2",
            "headline_part1",
            b"headline_part1",
            "headline_part2",
            b"headline_part2",
            "headline_part3",
            b"headline_part3",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "_headline_part1",
            b"_headline_part1",
            "_headline_part2",
            b"_headline_part2",
            "_headline_part3",
            b"_headline_part3",
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "description",
            b"description",
            "description2",
            b"description2",
            "headline_part1",
            b"headline_part1",
            "headline_part2",
            b"headline_part2",
            "headline_part3",
            b"headline_part3",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description2", b"_description2"],
    ) -> typing_extensions___Literal["description2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_headline_part1", b"_headline_part1"],
    ) -> typing_extensions___Literal["headline_part1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_headline_part2", b"_headline_part2"],
    ) -> typing_extensions___Literal["headline_part2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_headline_part3", b"_headline_part3"],
    ) -> typing_extensions___Literal["headline_part3"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_path1", b"_path1"]
    ) -> typing_extensions___Literal["path1"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_path2", b"_path2"]
    ) -> typing_extensions___Literal["path2"]: ...

type___ExpandedTextAdInfo = ExpandedTextAdInfo

class CallOnlyAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    country_code: typing___Text = ...
    phone_number: typing___Text = ...
    business_name: typing___Text = ...
    headline1: typing___Text = ...
    headline2: typing___Text = ...
    description1: typing___Text = ...
    description2: typing___Text = ...
    call_tracked: builtin___bool = ...
    disable_call_conversion: builtin___bool = ...
    phone_number_verification_url: typing___Text = ...
    conversion_action: typing___Text = ...
    conversion_reporting_state: google___ads___googleads___v6___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum.CallConversionReportingStateValue = ...
    def __init__(
        self,
        *,
        country_code: typing___Optional[typing___Text] = None,
        phone_number: typing___Optional[typing___Text] = None,
        business_name: typing___Optional[typing___Text] = None,
        headline1: typing___Optional[typing___Text] = None,
        headline2: typing___Optional[typing___Text] = None,
        description1: typing___Optional[typing___Text] = None,
        description2: typing___Optional[typing___Text] = None,
        call_tracked: typing___Optional[builtin___bool] = None,
        disable_call_conversion: typing___Optional[builtin___bool] = None,
        phone_number_verification_url: typing___Optional[typing___Text] = None,
        conversion_action: typing___Optional[typing___Text] = None,
        conversion_reporting_state: typing___Optional[
            google___ads___googleads___v6___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum.CallConversionReportingStateValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_business_name",
            b"_business_name",
            "_call_tracked",
            b"_call_tracked",
            "_conversion_action",
            b"_conversion_action",
            "_country_code",
            b"_country_code",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_disable_call_conversion",
            b"_disable_call_conversion",
            "_headline1",
            b"_headline1",
            "_headline2",
            b"_headline2",
            "_phone_number",
            b"_phone_number",
            "_phone_number_verification_url",
            b"_phone_number_verification_url",
            "business_name",
            b"business_name",
            "call_tracked",
            b"call_tracked",
            "conversion_action",
            b"conversion_action",
            "country_code",
            b"country_code",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "disable_call_conversion",
            b"disable_call_conversion",
            "headline1",
            b"headline1",
            "headline2",
            b"headline2",
            "phone_number",
            b"phone_number",
            "phone_number_verification_url",
            b"phone_number_verification_url",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_business_name",
            b"_business_name",
            "_call_tracked",
            b"_call_tracked",
            "_conversion_action",
            b"_conversion_action",
            "_country_code",
            b"_country_code",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_disable_call_conversion",
            b"_disable_call_conversion",
            "_headline1",
            b"_headline1",
            "_headline2",
            b"_headline2",
            "_phone_number",
            b"_phone_number",
            "_phone_number_verification_url",
            b"_phone_number_verification_url",
            "business_name",
            b"business_name",
            "call_tracked",
            b"call_tracked",
            "conversion_action",
            b"conversion_action",
            "conversion_reporting_state",
            b"conversion_reporting_state",
            "country_code",
            b"country_code",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "disable_call_conversion",
            b"disable_call_conversion",
            "headline1",
            b"headline1",
            "headline2",
            b"headline2",
            "phone_number",
            b"phone_number",
            "phone_number_verification_url",
            b"phone_number_verification_url",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_business_name", b"_business_name"],
    ) -> typing_extensions___Literal["business_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_call_tracked", b"_call_tracked"],
    ) -> typing_extensions___Literal["call_tracked"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions___Literal["conversion_action"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_country_code", b"_country_code"],
    ) -> typing_extensions___Literal["country_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description1", b"_description1"],
    ) -> typing_extensions___Literal["description1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description2", b"_description2"],
    ) -> typing_extensions___Literal["description2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_disable_call_conversion", b"_disable_call_conversion"
        ],
    ) -> typing_extensions___Literal["disable_call_conversion"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline1", b"_headline1"]
    ) -> typing_extensions___Literal["headline1"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline2", b"_headline2"]
    ) -> typing_extensions___Literal["headline2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_phone_number", b"_phone_number"],
    ) -> typing_extensions___Literal["phone_number"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_phone_number_verification_url", b"_phone_number_verification_url"
        ],
    ) -> typing_extensions___Literal["phone_number_verification_url"]: ...

type___CallOnlyAdInfo = CallOnlyAdInfo

class ExpandedDynamicSearchAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    description: typing___Text = ...
    description2: typing___Text = ...
    def __init__(
        self,
        *,
        description: typing___Optional[typing___Text] = None,
        description2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "description",
            b"description",
            "description2",
            b"description2",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "description",
            b"description",
            "description2",
            b"description2",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description2", b"_description2"],
    ) -> typing_extensions___Literal["description2"]: ...

type___ExpandedDynamicSearchAdInfo = ExpandedDynamicSearchAdInfo

class HotelAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___HotelAdInfo = HotelAdInfo

class ShoppingSmartAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___ShoppingSmartAdInfo = ShoppingSmartAdInfo

class ShoppingProductAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___ShoppingProductAdInfo = ShoppingProductAdInfo

class ShoppingComparisonListingAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    headline: typing___Text = ...
    def __init__(
        self, *, headline: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_headline", b"_headline", "headline", b"headline"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_headline", b"_headline", "headline", b"headline"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...

type___ShoppingComparisonListingAdInfo = ShoppingComparisonListingAdInfo

class GmailAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    header_image: typing___Text = ...
    marketing_image: typing___Text = ...
    marketing_image_headline: typing___Text = ...
    marketing_image_description: typing___Text = ...
    @property
    def teaser(self) -> type___GmailTeaser: ...
    @property
    def marketing_image_display_call_to_action(self) -> type___DisplayCallToAction: ...
    @property
    def product_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ProductImage
    ]: ...
    @property
    def product_videos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ProductVideo
    ]: ...
    def __init__(
        self,
        *,
        teaser: typing___Optional[type___GmailTeaser] = None,
        header_image: typing___Optional[typing___Text] = None,
        marketing_image: typing___Optional[typing___Text] = None,
        marketing_image_headline: typing___Optional[typing___Text] = None,
        marketing_image_description: typing___Optional[typing___Text] = None,
        marketing_image_display_call_to_action: typing___Optional[
            type___DisplayCallToAction
        ] = None,
        product_images: typing___Optional[
            typing___Iterable[type___ProductImage]
        ] = None,
        product_videos: typing___Optional[
            typing___Iterable[type___ProductVideo]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_header_image",
            b"_header_image",
            "_marketing_image",
            b"_marketing_image",
            "_marketing_image_description",
            b"_marketing_image_description",
            "_marketing_image_headline",
            b"_marketing_image_headline",
            "header_image",
            b"header_image",
            "marketing_image",
            b"marketing_image",
            "marketing_image_description",
            b"marketing_image_description",
            "marketing_image_display_call_to_action",
            b"marketing_image_display_call_to_action",
            "marketing_image_headline",
            b"marketing_image_headline",
            "teaser",
            b"teaser",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_header_image",
            b"_header_image",
            "_marketing_image",
            b"_marketing_image",
            "_marketing_image_description",
            b"_marketing_image_description",
            "_marketing_image_headline",
            b"_marketing_image_headline",
            "header_image",
            b"header_image",
            "marketing_image",
            b"marketing_image",
            "marketing_image_description",
            b"marketing_image_description",
            "marketing_image_display_call_to_action",
            b"marketing_image_display_call_to_action",
            "marketing_image_headline",
            b"marketing_image_headline",
            "product_images",
            b"product_images",
            "product_videos",
            b"product_videos",
            "teaser",
            b"teaser",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_header_image", b"_header_image"],
    ) -> typing_extensions___Literal["header_image"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_marketing_image", b"_marketing_image"
        ],
    ) -> typing_extensions___Literal["marketing_image"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_marketing_image_description", b"_marketing_image_description"
        ],
    ) -> typing_extensions___Literal["marketing_image_description"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_marketing_image_headline", b"_marketing_image_headline"
        ],
    ) -> typing_extensions___Literal["marketing_image_headline"]: ...

type___GmailAdInfo = GmailAdInfo

class GmailTeaser(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    headline: typing___Text = ...
    description: typing___Text = ...
    business_name: typing___Text = ...
    logo_image: typing___Text = ...
    def __init__(
        self,
        *,
        headline: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        business_name: typing___Optional[typing___Text] = None,
        logo_image: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_business_name",
            b"_business_name",
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "_logo_image",
            b"_logo_image",
            "business_name",
            b"business_name",
            "description",
            b"description",
            "headline",
            b"headline",
            "logo_image",
            b"logo_image",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_business_name",
            b"_business_name",
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "_logo_image",
            b"_logo_image",
            "business_name",
            b"business_name",
            "description",
            b"description",
            "headline",
            b"headline",
            "logo_image",
            b"logo_image",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_business_name", b"_business_name"],
    ) -> typing_extensions___Literal["business_name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_logo_image", b"_logo_image"]
    ) -> typing_extensions___Literal["logo_image"]: ...

type___GmailTeaser = GmailTeaser

class DisplayCallToAction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    text: typing___Text = ...
    text_color: typing___Text = ...
    url_collection_id: typing___Text = ...
    def __init__(
        self,
        *,
        text: typing___Optional[typing___Text] = None,
        text_color: typing___Optional[typing___Text] = None,
        url_collection_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_text",
            b"_text",
            "_text_color",
            b"_text_color",
            "_url_collection_id",
            b"_url_collection_id",
            "text",
            b"text",
            "text_color",
            b"text_color",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_text",
            b"_text",
            "_text_color",
            b"_text_color",
            "_url_collection_id",
            b"_url_collection_id",
            "text",
            b"text",
            "text_color",
            b"text_color",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text_color", b"_text_color"]
    ) -> typing_extensions___Literal["text_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_url_collection_id", b"_url_collection_id"
        ],
    ) -> typing_extensions___Literal["url_collection_id"]: ...

type___DisplayCallToAction = DisplayCallToAction

class ProductImage(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    product_image: typing___Text = ...
    description: typing___Text = ...
    @property
    def display_call_to_action(self) -> type___DisplayCallToAction: ...
    def __init__(
        self,
        *,
        product_image: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        display_call_to_action: typing___Optional[type___DisplayCallToAction] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_product_image",
            b"_product_image",
            "description",
            b"description",
            "display_call_to_action",
            b"display_call_to_action",
            "product_image",
            b"product_image",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_product_image",
            b"_product_image",
            "description",
            b"description",
            "display_call_to_action",
            b"display_call_to_action",
            "product_image",
            b"product_image",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_product_image", b"_product_image"],
    ) -> typing_extensions___Literal["product_image"]: ...

type___ProductImage = ProductImage

class ProductVideo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    product_video: typing___Text = ...
    def __init__(
        self, *, product_video: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_product_video", b"_product_video", "product_video", b"product_video"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_product_video", b"_product_video", "product_video", b"product_video"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_product_video", b"_product_video"],
    ) -> typing_extensions___Literal["product_video"]: ...

type___ProductVideo = ProductVideo

class ImageAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    pixel_width: builtin___int = ...
    pixel_height: builtin___int = ...
    image_url: typing___Text = ...
    preview_pixel_width: builtin___int = ...
    preview_pixel_height: builtin___int = ...
    preview_image_url: typing___Text = ...
    mime_type: google___ads___googleads___v6___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue = ...
    name: typing___Text = ...
    media_file: typing___Text = ...
    data: builtin___bytes = ...
    ad_id_to_copy_image_from: builtin___int = ...
    def __init__(
        self,
        *,
        pixel_width: typing___Optional[builtin___int] = None,
        pixel_height: typing___Optional[builtin___int] = None,
        image_url: typing___Optional[typing___Text] = None,
        preview_pixel_width: typing___Optional[builtin___int] = None,
        preview_pixel_height: typing___Optional[builtin___int] = None,
        preview_image_url: typing___Optional[typing___Text] = None,
        mime_type: typing___Optional[
            google___ads___googleads___v6___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue
        ] = None,
        name: typing___Optional[typing___Text] = None,
        media_file: typing___Optional[typing___Text] = None,
        data: typing___Optional[builtin___bytes] = None,
        ad_id_to_copy_image_from: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_image_url",
            b"_image_url",
            "_name",
            b"_name",
            "_pixel_height",
            b"_pixel_height",
            "_pixel_width",
            b"_pixel_width",
            "_preview_image_url",
            b"_preview_image_url",
            "_preview_pixel_height",
            b"_preview_pixel_height",
            "_preview_pixel_width",
            b"_preview_pixel_width",
            "ad_id_to_copy_image_from",
            b"ad_id_to_copy_image_from",
            "data",
            b"data",
            "image",
            b"image",
            "image_url",
            b"image_url",
            "media_file",
            b"media_file",
            "name",
            b"name",
            "pixel_height",
            b"pixel_height",
            "pixel_width",
            b"pixel_width",
            "preview_image_url",
            b"preview_image_url",
            "preview_pixel_height",
            b"preview_pixel_height",
            "preview_pixel_width",
            b"preview_pixel_width",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_image_url",
            b"_image_url",
            "_name",
            b"_name",
            "_pixel_height",
            b"_pixel_height",
            "_pixel_width",
            b"_pixel_width",
            "_preview_image_url",
            b"_preview_image_url",
            "_preview_pixel_height",
            b"_preview_pixel_height",
            "_preview_pixel_width",
            b"_preview_pixel_width",
            "ad_id_to_copy_image_from",
            b"ad_id_to_copy_image_from",
            "data",
            b"data",
            "image",
            b"image",
            "image_url",
            b"image_url",
            "media_file",
            b"media_file",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "pixel_height",
            b"pixel_height",
            "pixel_width",
            b"pixel_width",
            "preview_image_url",
            b"preview_image_url",
            "preview_pixel_height",
            b"preview_pixel_height",
            "preview_pixel_width",
            b"preview_pixel_width",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_image_url", b"_image_url"]
    ) -> typing_extensions___Literal["image_url"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_pixel_height", b"_pixel_height"],
    ) -> typing_extensions___Literal["pixel_height"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_pixel_width", b"_pixel_width"]
    ) -> typing_extensions___Literal["pixel_width"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_preview_image_url", b"_preview_image_url"
        ],
    ) -> typing_extensions___Literal["preview_image_url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_preview_pixel_height", b"_preview_pixel_height"
        ],
    ) -> typing_extensions___Literal["preview_pixel_height"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_preview_pixel_width", b"_preview_pixel_width"
        ],
    ) -> typing_extensions___Literal["preview_pixel_width"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["image", b"image"]
    ) -> typing_extensions___Literal[
        "media_file", "data", "ad_id_to_copy_image_from"
    ]: ...

type___ImageAdInfo = ImageAdInfo

class VideoBumperInStreamAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    companion_banner: typing___Text = ...
    def __init__(
        self, *, companion_banner: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions___Literal["companion_banner"]: ...

type___VideoBumperInStreamAdInfo = VideoBumperInStreamAdInfo

class VideoNonSkippableInStreamAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    companion_banner: typing___Text = ...
    def __init__(
        self, *, companion_banner: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions___Literal["companion_banner"]: ...

type___VideoNonSkippableInStreamAdInfo = VideoNonSkippableInStreamAdInfo

class VideoTrueViewInStreamAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    action_button_label: typing___Text = ...
    action_headline: typing___Text = ...
    companion_banner: typing___Text = ...
    def __init__(
        self,
        *,
        action_button_label: typing___Optional[typing___Text] = None,
        action_headline: typing___Optional[typing___Text] = None,
        companion_banner: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_action_button_label",
            b"_action_button_label",
            "_action_headline",
            b"_action_headline",
            "_companion_banner",
            b"_companion_banner",
            "action_button_label",
            b"action_button_label",
            "action_headline",
            b"action_headline",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_action_button_label",
            b"_action_button_label",
            "_action_headline",
            b"_action_headline",
            "_companion_banner",
            b"_companion_banner",
            "action_button_label",
            b"action_button_label",
            "action_headline",
            b"action_headline",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_action_button_label", b"_action_button_label"
        ],
    ) -> typing_extensions___Literal["action_button_label"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_action_headline", b"_action_headline"
        ],
    ) -> typing_extensions___Literal["action_headline"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions___Literal["companion_banner"]: ...

type___VideoTrueViewInStreamAdInfo = VideoTrueViewInStreamAdInfo

class VideoOutstreamAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    headline: typing___Text = ...
    description: typing___Text = ...
    def __init__(
        self,
        *,
        headline: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "description",
            b"description",
            "headline",
            b"headline",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "description",
            b"description",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...

type___VideoOutstreamAdInfo = VideoOutstreamAdInfo

class VideoTrueViewDiscoveryAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    headline: typing___Text = ...
    description1: typing___Text = ...
    description2: typing___Text = ...
    def __init__(
        self,
        *,
        headline: typing___Optional[typing___Text] = None,
        description1: typing___Optional[typing___Text] = None,
        description2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description1", b"_description1"],
    ) -> typing_extensions___Literal["description1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description2", b"_description2"],
    ) -> typing_extensions___Literal["description2"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...

type___VideoTrueViewDiscoveryAdInfo = VideoTrueViewDiscoveryAdInfo

class VideoAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    media_file: typing___Text = ...
    @property
    def in_stream(self) -> type___VideoTrueViewInStreamAdInfo: ...
    @property
    def bumper(self) -> type___VideoBumperInStreamAdInfo: ...
    @property
    def out_stream(self) -> type___VideoOutstreamAdInfo: ...
    @property
    def non_skippable(self) -> type___VideoNonSkippableInStreamAdInfo: ...
    @property
    def discovery(self) -> type___VideoTrueViewDiscoveryAdInfo: ...
    def __init__(
        self,
        *,
        media_file: typing___Optional[typing___Text] = None,
        in_stream: typing___Optional[type___VideoTrueViewInStreamAdInfo] = None,
        bumper: typing___Optional[type___VideoBumperInStreamAdInfo] = None,
        out_stream: typing___Optional[type___VideoOutstreamAdInfo] = None,
        non_skippable: typing___Optional[type___VideoNonSkippableInStreamAdInfo] = None,
        discovery: typing___Optional[type___VideoTrueViewDiscoveryAdInfo] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_media_file",
            b"_media_file",
            "bumper",
            b"bumper",
            "discovery",
            b"discovery",
            "format",
            b"format",
            "in_stream",
            b"in_stream",
            "media_file",
            b"media_file",
            "non_skippable",
            b"non_skippable",
            "out_stream",
            b"out_stream",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_media_file",
            b"_media_file",
            "bumper",
            b"bumper",
            "discovery",
            b"discovery",
            "format",
            b"format",
            "in_stream",
            b"in_stream",
            "media_file",
            b"media_file",
            "non_skippable",
            b"non_skippable",
            "out_stream",
            b"out_stream",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_media_file", b"_media_file"]
    ) -> typing_extensions___Literal["media_file"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["format", b"format"]
    ) -> typing_extensions___Literal[
        "in_stream", "bumper", "out_stream", "non_skippable", "discovery"
    ]: ...

type___VideoAdInfo = VideoAdInfo

class VideoResponsiveAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def long_headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def call_to_actions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
    ]: ...
    @property
    def companion_banners(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        long_headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        descriptions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        call_to_actions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        videos: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
            ]
        ] = None,
        companion_banners: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "call_to_actions",
            b"call_to_actions",
            "companion_banners",
            b"companion_banners",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "long_headlines",
            b"long_headlines",
            "videos",
            b"videos",
        ],
    ) -> None: ...

type___VideoResponsiveAdInfo = VideoResponsiveAdInfo

class ResponsiveSearchAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    path1: typing___Text = ...
    path2: typing___Text = ...
    @property
    def headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        descriptions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        path1: typing___Optional[typing___Text] = None,
        path2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_path1", b"_path1"]
    ) -> typing_extensions___Literal["path1"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_path2", b"_path2"]
    ) -> typing_extensions___Literal["path2"]: ...

type___ResponsiveSearchAdInfo = ResponsiveSearchAdInfo

class LegacyResponsiveDisplayAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    short_headline: typing___Text = ...
    long_headline: typing___Text = ...
    description: typing___Text = ...
    business_name: typing___Text = ...
    allow_flexible_color: builtin___bool = ...
    accent_color: typing___Text = ...
    main_color: typing___Text = ...
    call_to_action_text: typing___Text = ...
    logo_image: typing___Text = ...
    square_logo_image: typing___Text = ...
    marketing_image: typing___Text = ...
    square_marketing_image: typing___Text = ...
    format_setting: google___ads___googleads___v6___enums___display_ad_format_setting_pb2___DisplayAdFormatSettingEnum.DisplayAdFormatSettingValue = ...
    price_prefix: typing___Text = ...
    promo_text: typing___Text = ...
    def __init__(
        self,
        *,
        short_headline: typing___Optional[typing___Text] = None,
        long_headline: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        business_name: typing___Optional[typing___Text] = None,
        allow_flexible_color: typing___Optional[builtin___bool] = None,
        accent_color: typing___Optional[typing___Text] = None,
        main_color: typing___Optional[typing___Text] = None,
        call_to_action_text: typing___Optional[typing___Text] = None,
        logo_image: typing___Optional[typing___Text] = None,
        square_logo_image: typing___Optional[typing___Text] = None,
        marketing_image: typing___Optional[typing___Text] = None,
        square_marketing_image: typing___Optional[typing___Text] = None,
        format_setting: typing___Optional[
            google___ads___googleads___v6___enums___display_ad_format_setting_pb2___DisplayAdFormatSettingEnum.DisplayAdFormatSettingValue
        ] = None,
        price_prefix: typing___Optional[typing___Text] = None,
        promo_text: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_description",
            b"_description",
            "_logo_image",
            b"_logo_image",
            "_long_headline",
            b"_long_headline",
            "_main_color",
            b"_main_color",
            "_marketing_image",
            b"_marketing_image",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "_short_headline",
            b"_short_headline",
            "_square_logo_image",
            b"_square_logo_image",
            "_square_marketing_image",
            b"_square_marketing_image",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "description",
            b"description",
            "logo_image",
            b"logo_image",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_image",
            b"marketing_image",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "short_headline",
            b"short_headline",
            "square_logo_image",
            b"square_logo_image",
            "square_marketing_image",
            b"square_marketing_image",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_description",
            b"_description",
            "_logo_image",
            b"_logo_image",
            "_long_headline",
            b"_long_headline",
            "_main_color",
            b"_main_color",
            "_marketing_image",
            b"_marketing_image",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "_short_headline",
            b"_short_headline",
            "_square_logo_image",
            b"_square_logo_image",
            "_square_marketing_image",
            b"_square_marketing_image",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "description",
            b"description",
            "format_setting",
            b"format_setting",
            "logo_image",
            b"logo_image",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_image",
            b"marketing_image",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "short_headline",
            b"short_headline",
            "square_logo_image",
            b"square_logo_image",
            "square_marketing_image",
            b"square_marketing_image",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_accent_color", b"_accent_color"],
    ) -> typing_extensions___Literal["accent_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_allow_flexible_color", b"_allow_flexible_color"
        ],
    ) -> typing_extensions___Literal["allow_flexible_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_business_name", b"_business_name"],
    ) -> typing_extensions___Literal["business_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_call_to_action_text", b"_call_to_action_text"
        ],
    ) -> typing_extensions___Literal["call_to_action_text"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_logo_image", b"_logo_image"]
    ) -> typing_extensions___Literal["logo_image"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_long_headline", b"_long_headline"],
    ) -> typing_extensions___Literal["long_headline"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_main_color", b"_main_color"]
    ) -> typing_extensions___Literal["main_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_marketing_image", b"_marketing_image"
        ],
    ) -> typing_extensions___Literal["marketing_image"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_price_prefix", b"_price_prefix"],
    ) -> typing_extensions___Literal["price_prefix"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_promo_text", b"_promo_text"]
    ) -> typing_extensions___Literal["promo_text"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_short_headline", b"_short_headline"],
    ) -> typing_extensions___Literal["short_headline"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_square_logo_image", b"_square_logo_image"
        ],
    ) -> typing_extensions___Literal["square_logo_image"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_square_marketing_image", b"_square_marketing_image"
        ],
    ) -> typing_extensions___Literal["square_marketing_image"]: ...

type___LegacyResponsiveDisplayAdInfo = LegacyResponsiveDisplayAdInfo

class AppAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def mandatory_ad_text(
        self,
    ) -> google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset: ...
    @property
    def headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def youtube_videos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
    ]: ...
    @property
    def html5_media_bundles(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdMediaBundleAsset
    ]: ...
    def __init__(
        self,
        *,
        mandatory_ad_text: typing___Optional[
            google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
        ] = None,
        headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        descriptions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        youtube_videos: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
            ]
        ] = None,
        html5_media_bundles: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdMediaBundleAsset
            ]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "mandatory_ad_text", b"mandatory_ad_text"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "html5_media_bundles",
            b"html5_media_bundles",
            "images",
            b"images",
            "mandatory_ad_text",
            b"mandatory_ad_text",
            "youtube_videos",
            b"youtube_videos",
        ],
    ) -> None: ...

type___AppAdInfo = AppAdInfo

class AppEngagementAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        descriptions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        videos: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "images",
            b"images",
            "videos",
            b"videos",
        ],
    ) -> None: ...

type___AppEngagementAdInfo = AppEngagementAdInfo

class LegacyAppInstallAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    app_id: typing___Text = ...
    app_store: google___ads___googleads___v6___enums___legacy_app_install_ad_app_store_pb2___LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStoreValue = ...
    headline: typing___Text = ...
    description1: typing___Text = ...
    description2: typing___Text = ...
    def __init__(
        self,
        *,
        app_id: typing___Optional[typing___Text] = None,
        app_store: typing___Optional[
            google___ads___googleads___v6___enums___legacy_app_install_ad_app_store_pb2___LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStoreValue
        ] = None,
        headline: typing___Optional[typing___Text] = None,
        description1: typing___Optional[typing___Text] = None,
        description2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_app_id",
            b"_app_id",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "app_id",
            b"app_id",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_app_id",
            b"_app_id",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "app_id",
            b"app_id",
            "app_store",
            b"app_store",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_app_id", b"_app_id"]
    ) -> typing_extensions___Literal["app_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description1", b"_description1"],
    ) -> typing_extensions___Literal["description1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_description2", b"_description2"],
    ) -> typing_extensions___Literal["description2"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...

type___LegacyAppInstallAdInfo = LegacyAppInstallAdInfo

class ResponsiveDisplayAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    business_name: typing___Text = ...
    main_color: typing___Text = ...
    accent_color: typing___Text = ...
    allow_flexible_color: builtin___bool = ...
    call_to_action_text: typing___Text = ...
    price_prefix: typing___Text = ...
    promo_text: typing___Text = ...
    format_setting: google___ads___googleads___v6___enums___display_ad_format_setting_pb2___DisplayAdFormatSettingEnum.DisplayAdFormatSettingValue = ...
    @property
    def marketing_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def square_marketing_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def logo_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def square_logo_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def long_headline(
        self,
    ) -> google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset: ...
    @property
    def descriptions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def youtube_videos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
    ]: ...
    @property
    def control_spec(self) -> type___ResponsiveDisplayAdControlSpec: ...
    def __init__(
        self,
        *,
        marketing_images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        square_marketing_images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        logo_images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        square_logo_images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        long_headline: typing___Optional[
            google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
        ] = None,
        descriptions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        youtube_videos: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
            ]
        ] = None,
        business_name: typing___Optional[typing___Text] = None,
        main_color: typing___Optional[typing___Text] = None,
        accent_color: typing___Optional[typing___Text] = None,
        allow_flexible_color: typing___Optional[builtin___bool] = None,
        call_to_action_text: typing___Optional[typing___Text] = None,
        price_prefix: typing___Optional[typing___Text] = None,
        promo_text: typing___Optional[typing___Text] = None,
        format_setting: typing___Optional[
            google___ads___googleads___v6___enums___display_ad_format_setting_pb2___DisplayAdFormatSettingEnum.DisplayAdFormatSettingValue
        ] = None,
        control_spec: typing___Optional[type___ResponsiveDisplayAdControlSpec] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_main_color",
            b"_main_color",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "control_spec",
            b"control_spec",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_main_color",
            b"_main_color",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "control_spec",
            b"control_spec",
            "descriptions",
            b"descriptions",
            "format_setting",
            b"format_setting",
            "headlines",
            b"headlines",
            "logo_images",
            b"logo_images",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_images",
            b"marketing_images",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "square_logo_images",
            b"square_logo_images",
            "square_marketing_images",
            b"square_marketing_images",
            "youtube_videos",
            b"youtube_videos",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_accent_color", b"_accent_color"],
    ) -> typing_extensions___Literal["accent_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_allow_flexible_color", b"_allow_flexible_color"
        ],
    ) -> typing_extensions___Literal["allow_flexible_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_business_name", b"_business_name"],
    ) -> typing_extensions___Literal["business_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_call_to_action_text", b"_call_to_action_text"
        ],
    ) -> typing_extensions___Literal["call_to_action_text"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_main_color", b"_main_color"]
    ) -> typing_extensions___Literal["main_color"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_price_prefix", b"_price_prefix"],
    ) -> typing_extensions___Literal["price_prefix"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_promo_text", b"_promo_text"]
    ) -> typing_extensions___Literal["promo_text"]: ...

type___ResponsiveDisplayAdInfo = ResponsiveDisplayAdInfo

class LocalAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    path1: typing___Text = ...
    path2: typing___Text = ...
    @property
    def headlines(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def call_to_actions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
    ]: ...
    @property
    def marketing_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def logo_images(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        descriptions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        call_to_actions: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdTextAsset
            ]
        ] = None,
        marketing_images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        logo_images: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdImageAsset
            ]
        ] = None,
        videos: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___ad_asset_pb2___AdVideoAsset
            ]
        ] = None,
        path1: typing___Optional[typing___Text] = None,
        path2: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "call_to_actions",
            b"call_to_actions",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "logo_images",
            b"logo_images",
            "marketing_images",
            b"marketing_images",
            "path1",
            b"path1",
            "path2",
            b"path2",
            "videos",
            b"videos",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_path1", b"_path1"]
    ) -> typing_extensions___Literal["path1"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_path2", b"_path2"]
    ) -> typing_extensions___Literal["path2"]: ...

type___LocalAdInfo = LocalAdInfo

class DisplayUploadAdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    display_upload_product_type: google___ads___googleads___v6___enums___display_upload_product_type_pb2___DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue = ...
    @property
    def media_bundle(
        self,
    ) -> google___ads___googleads___v6___common___ad_asset_pb2___AdMediaBundleAsset: ...
    def __init__(
        self,
        *,
        display_upload_product_type: typing___Optional[
            google___ads___googleads___v6___enums___display_upload_product_type_pb2___DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue
        ] = None,
        media_bundle: typing___Optional[
            google___ads___googleads___v6___common___ad_asset_pb2___AdMediaBundleAsset
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "media_asset", b"media_asset", "media_bundle", b"media_bundle"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "display_upload_product_type",
            b"display_upload_product_type",
            "media_asset",
            b"media_asset",
            "media_bundle",
            b"media_bundle",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["media_asset", b"media_asset"]
    ) -> typing_extensions___Literal["media_bundle"]: ...

type___DisplayUploadAdInfo = DisplayUploadAdInfo

class ResponsiveDisplayAdControlSpec(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    enable_asset_enhancements: builtin___bool = ...
    enable_autogen_video: builtin___bool = ...
    def __init__(
        self,
        *,
        enable_asset_enhancements: typing___Optional[builtin___bool] = None,
        enable_autogen_video: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "enable_asset_enhancements",
            b"enable_asset_enhancements",
            "enable_autogen_video",
            b"enable_autogen_video",
        ],
    ) -> None: ...

type___ResponsiveDisplayAdControlSpec = ResponsiveDisplayAdControlSpec



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExtensionFeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ExtensionFeedItemErrorValue = typing___NewType(
        "ExtensionFeedItemErrorValue", builtin___int
    )
    type___ExtensionFeedItemErrorValue = ExtensionFeedItemErrorValue
    ExtensionFeedItemError: _ExtensionFeedItemError
    class _ExtensionFeedItemError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 1
        )
        VALUE_OUT_OF_RANGE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 2
        )
        URL_LIST_TOO_LONG = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 3
        )
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 4
        )
        CANNOT_SET_WITH_FINAL_URLS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 5
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 6
        )
        INVALID_PHONE_NUMBER = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 7
        )
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 8
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 9
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 10
        )
        DISALLOWED_NUMBER_TYPE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 11
        )
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 12
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 13
        )
        INVALID_CALL_CONVERSION_ACTION = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 14
        )
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_CALLTRACKING = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 47
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 16
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 17
        )
        INVALID_APP_ID = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 18
        )
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 19
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 20
        )
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 21
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 22
        )
        INCONSISTENT_CURRENCY_CODES = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 23
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 24
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 25
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 26
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 27
        )
        UNSUPPORTED_VALUE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 28
        )
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 29
        )
        INVALID_DEVICE_PREFERENCE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 30
        )
        INVALID_SCHEDULE_END = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 31
        )
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 32
        )
        INVALID_SNIPPETS_HEADER = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 33
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 34
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 35
        )
        CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 36
        )
        EXTENSION_TYPE_MISMATCH = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 37
        )
        EXTENSION_SUBTYPE_REQUIRED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 38
        )
        EXTENSION_TYPE_UNSUPPORTED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 39
        )
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 40
        )
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 41
        )
        INVALID_PRICE_FORMAT = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 42
        )
        PROMOTION_INVALID_TIME = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 43
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 44
        )
        CONCRETE_EXTENSION_TYPE_REQUIRED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 45
        )
        SCHEDULE_END_NOT_AFTER_START = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 46
        )
    UNSPECIFIED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 0
    )
    UNKNOWN = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 1)
    VALUE_OUT_OF_RANGE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 2
    )
    URL_LIST_TOO_LONG = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 3
    )
    CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 4
    )
    CANNOT_SET_WITH_FINAL_URLS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 5
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 6
    )
    INVALID_PHONE_NUMBER = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 7
    )
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 8
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 9
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 10
    )
    DISALLOWED_NUMBER_TYPE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 11
    )
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 12
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 13
    )
    INVALID_CALL_CONVERSION_ACTION = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 14
    )
    CUSTOMER_NOT_ON_ALLOWLIST_FOR_CALLTRACKING = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 47
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 16
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 17
    )
    INVALID_APP_ID = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 18
    )
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 19
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 20
    )
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 21
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 22
    )
    INCONSISTENT_CURRENCY_CODES = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 23
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 24
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 25
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 26
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 27
    )
    UNSUPPORTED_VALUE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 28
    )
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 29
    )
    INVALID_DEVICE_PREFERENCE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 30
    )
    INVALID_SCHEDULE_END = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 31
    )
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 32
    )
    INVALID_SNIPPETS_HEADER = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 33
    )
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 34
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 35
    )
    CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 36
    )
    EXTENSION_TYPE_MISMATCH = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 37
    )
    EXTENSION_SUBTYPE_REQUIRED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 38
    )
    EXTENSION_TYPE_UNSUPPORTED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 39
    )
    CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 40
    )
    CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 41
    )
    INVALID_PRICE_FORMAT = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 42
    )
    PROMOTION_INVALID_TIME = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 43
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 44
    )
    CONCRETE_EXTENSION_TYPE_REQUIRED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 45
    )
    SCHEDULE_END_NOT_AFTER_START = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 46
    )
    type___ExtensionFeedItemError = ExtensionFeedItemError
    def __init__(self,) -> None: ...

type___ExtensionFeedItemErrorEnum = ExtensionFeedItemErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CallPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CallPlaceholderFieldValue = typing___NewType(
        "CallPlaceholderFieldValue", builtin___int
    )
    type___CallPlaceholderFieldValue = CallPlaceholderFieldValue
    CallPlaceholderField: _CallPlaceholderField
    class _CallPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CallPlaceholderFieldEnum.CallPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 1)
        PHONE_NUMBER = typing___cast(
            CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 2
        )
        COUNTRY_CODE = typing___cast(
            CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 3
        )
        TRACKED = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 4)
        CONVERSION_TYPE_ID = typing___cast(
            CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 5
        )
        CONVERSION_REPORTING_STATE = typing___cast(
            CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 6
        )
    UNSPECIFIED = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 1)
    PHONE_NUMBER = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 2)
    COUNTRY_CODE = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 3)
    TRACKED = typing___cast(CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 4)
    CONVERSION_TYPE_ID = typing___cast(
        CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 5
    )
    CONVERSION_REPORTING_STATE = typing___cast(
        CallPlaceholderFieldEnum.CallPlaceholderFieldValue, 6
    )
    type___CallPlaceholderField = CallPlaceholderField
    def __init__(self,) -> None: ...

type___CallPlaceholderFieldEnum = CallPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ManagerLinkStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ManagerLinkStatusValue = typing___NewType("ManagerLinkStatusValue", builtin___int)
    type___ManagerLinkStatusValue = ManagerLinkStatusValue
    ManagerLinkStatus: _ManagerLinkStatus
    class _ManagerLinkStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ManagerLinkStatusEnum.ManagerLinkStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 0)
        UNKNOWN = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 1)
        ACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 2)
        INACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 3)
        PENDING = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 4)
        REFUSED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 5)
        CANCELED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 6)
    UNSPECIFIED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 0)
    UNKNOWN = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 1)
    ACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 2)
    INACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 3)
    PENDING = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 4)
    REFUSED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 5)
    CANCELED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 6)
    type___ManagerLinkStatus = ManagerLinkStatus
    def __init__(self,) -> None: ...

type___ManagerLinkStatusEnum = ManagerLinkStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MimeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MimeTypeValue = typing___NewType("MimeTypeValue", builtin___int)
    type___MimeTypeValue = MimeTypeValue
    MimeType: _MimeType
    class _MimeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MimeTypeEnum.MimeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MimeTypeEnum.MimeTypeValue, 0)
        UNKNOWN = typing___cast(MimeTypeEnum.MimeTypeValue, 1)
        IMAGE_JPEG = typing___cast(MimeTypeEnum.MimeTypeValue, 2)
        IMAGE_GIF = typing___cast(MimeTypeEnum.MimeTypeValue, 3)
        IMAGE_PNG = typing___cast(MimeTypeEnum.MimeTypeValue, 4)
        FLASH = typing___cast(MimeTypeEnum.MimeTypeValue, 5)
        TEXT_HTML = typing___cast(MimeTypeEnum.MimeTypeValue, 6)
        PDF = typing___cast(MimeTypeEnum.MimeTypeValue, 7)
        MSWORD = typing___cast(MimeTypeEnum.MimeTypeValue, 8)
        MSEXCEL = typing___cast(MimeTypeEnum.MimeTypeValue, 9)
        RTF = typing___cast(MimeTypeEnum.MimeTypeValue, 10)
        AUDIO_WAV = typing___cast(MimeTypeEnum.MimeTypeValue, 11)
        AUDIO_MP3 = typing___cast(MimeTypeEnum.MimeTypeValue, 12)
        HTML5_AD_ZIP = typing___cast(MimeTypeEnum.MimeTypeValue, 13)
    UNSPECIFIED = typing___cast(MimeTypeEnum.MimeTypeValue, 0)
    UNKNOWN = typing___cast(MimeTypeEnum.MimeTypeValue, 1)
    IMAGE_JPEG = typing___cast(MimeTypeEnum.MimeTypeValue, 2)
    IMAGE_GIF = typing___cast(MimeTypeEnum.MimeTypeValue, 3)
    IMAGE_PNG = typing___cast(MimeTypeEnum.MimeTypeValue, 4)
    FLASH = typing___cast(MimeTypeEnum.MimeTypeValue, 5)
    TEXT_HTML = typing___cast(MimeTypeEnum.MimeTypeValue, 6)
    PDF = typing___cast(MimeTypeEnum.MimeTypeValue, 7)
    MSWORD = typing___cast(MimeTypeEnum.MimeTypeValue, 8)
    MSEXCEL = typing___cast(MimeTypeEnum.MimeTypeValue, 9)
    RTF = typing___cast(MimeTypeEnum.MimeTypeValue, 10)
    AUDIO_WAV = typing___cast(MimeTypeEnum.MimeTypeValue, 11)
    AUDIO_MP3 = typing___cast(MimeTypeEnum.MimeTypeValue, 12)
    HTML5_AD_ZIP = typing___cast(MimeTypeEnum.MimeTypeValue, 13)
    type___MimeType = MimeType
    def __init__(self,) -> None: ...

type___MimeTypeEnum = MimeTypeEnum



from typing import Any, Optional

class CampaignExperimentServiceStub:
    GetCampaignExperiment: Any = ...
    CreateCampaignExperiment: Any = ...
    MutateCampaignExperiments: Any = ...
    GraduateCampaignExperiment: Any = ...
    PromoteCampaignExperiment: Any = ...
    EndCampaignExperiment: Any = ...
    ListCampaignExperimentAsyncErrors: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignExperimentServiceServicer:
    def GetCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def CreateCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def MutateCampaignExperiments(self, request: Any, context: Any) -> None: ...
    def GraduateCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def PromoteCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def EndCampaignExperiment(self, request: Any, context: Any) -> None: ...
    def ListCampaignExperimentAsyncErrors(self, request: Any, context: Any) -> None: ...

def add_CampaignExperimentServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class CampaignExperimentService:
    @staticmethod
    def GetCampaignExperiment(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def CreateCampaignExperiment(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateCampaignExperiments(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GraduateCampaignExperiment(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def PromoteCampaignExperiment(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def EndCampaignExperiment(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def ListCampaignExperimentAsyncErrors(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any

class InvoiceServiceStub:
    ListInvoices: Any = ...
    def __init__(self, channel: Any) -> None: ...

class InvoiceServiceServicer:
    def ListInvoices(self, request: Any, context: Any) -> None: ...

def add_InvoiceServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ManagerLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ManagerLinkErrorValue = typing___NewType("ManagerLinkErrorValue", builtin___int)
    type___ManagerLinkErrorValue = ManagerLinkErrorValue
    ManagerLinkError: _ManagerLinkError
    class _ManagerLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ManagerLinkErrorEnum.ManagerLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 0)
        UNKNOWN = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 1)
        ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 2
        )
        TOO_MANY_MANAGERS = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 3)
        TOO_MANY_INVITES = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 4)
        ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 5
        )
        ALREADY_MANAGED_BY_THIS_MANAGER = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 6
        )
        ALREADY_MANAGED_IN_HIERARCHY = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 7
        )
        DUPLICATE_CHILD_FOUND = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 8
        )
        CLIENT_HAS_NO_ADMIN_USER = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 9
        )
        MAX_DEPTH_EXCEEDED = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 10
        )
        CYCLE_NOT_ALLOWED = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 11
        )
        TOO_MANY_ACCOUNTS = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 12
        )
        TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 13
        )
        NON_OWNER_USER_CANNOT_MODIFY_LINK = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 14
        )
        SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 15
        )
        CLIENT_OUTSIDE_TREE = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 16
        )
        INVALID_STATUS_CHANGE = typing___cast(
            ManagerLinkErrorEnum.ManagerLinkErrorValue, 17
        )
        INVALID_CHANGE = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 18)
    UNSPECIFIED = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 0)
    UNKNOWN = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 1)
    ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 2
    )
    TOO_MANY_MANAGERS = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 3)
    TOO_MANY_INVITES = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 4)
    ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 5
    )
    ALREADY_MANAGED_BY_THIS_MANAGER = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 6
    )
    ALREADY_MANAGED_IN_HIERARCHY = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 7
    )
    DUPLICATE_CHILD_FOUND = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 8)
    CLIENT_HAS_NO_ADMIN_USER = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 9
    )
    MAX_DEPTH_EXCEEDED = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 10)
    CYCLE_NOT_ALLOWED = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 11)
    TOO_MANY_ACCOUNTS = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 12)
    TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 13
    )
    NON_OWNER_USER_CANNOT_MODIFY_LINK = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 14
    )
    SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 15
    )
    CLIENT_OUTSIDE_TREE = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 16)
    INVALID_STATUS_CHANGE = typing___cast(
        ManagerLinkErrorEnum.ManagerLinkErrorValue, 17
    )
    INVALID_CHANGE = typing___cast(ManagerLinkErrorEnum.ManagerLinkErrorValue, 18)
    type___ManagerLinkError = ManagerLinkError
    def __init__(self,) -> None: ...

type___ManagerLinkErrorEnum = ManagerLinkErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.criteria_pb2 import (
    DeviceInfo as google___ads___googleads___v3___common___criteria_pb2___DeviceInfo,
    GenderInfo as google___ads___googleads___v3___common___criteria_pb2___GenderInfo,
)
from google.ads.google_ads.v3.proto.enums.reach_plan_ad_length_pb2 import (
    ReachPlanAdLengthEnum as google___ads___googleads___v3___enums___reach_plan_ad_length_pb2___ReachPlanAdLengthEnum,
)
from google.ads.google_ads.v3.proto.enums.reach_plan_age_range_pb2 import (
    ReachPlanAgeRangeEnum as google___ads___googleads___v3___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum,
)
from google.ads.google_ads.v3.proto.enums.reach_plan_network_pb2 import (
    ReachPlanNetworkEnum as google___ads___googleads___v3___enums___reach_plan_network_pb2___ReachPlanNetworkEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ListPlannableLocationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___ListPlannableLocationsRequest = ListPlannableLocationsRequest

class ListPlannableLocationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def plannable_locations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PlannableLocation
    ]: ...
    def __init__(
        self,
        *,
        plannable_locations: typing___Optional[
            typing___Iterable[type___PlannableLocation]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "plannable_locations", b"plannable_locations"
        ],
    ) -> None: ...

type___ListPlannableLocationsResponse = ListPlannableLocationsResponse

class PlannableLocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def parent_country_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        id: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        parent_country_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "id", b"id", "name", b"name", "parent_country_id", b"parent_country_id"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "id", b"id", "name", b"name", "parent_country_id", b"parent_country_id"
        ],
    ) -> None: ...

type___PlannableLocation = PlannableLocation

class ListPlannableProductsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def plannable_location_id(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        plannable_location_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "plannable_location_id", b"plannable_location_id"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "plannable_location_id", b"plannable_location_id"
        ],
    ) -> None: ...

type___ListPlannableProductsRequest = ListPlannableProductsRequest

class ListPlannableProductsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def product_metadata(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ProductMetadata
    ]: ...
    def __init__(
        self,
        *,
        product_metadata: typing___Optional[
            typing___Iterable[type___ProductMetadata]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "product_metadata", b"product_metadata"
        ],
    ) -> None: ...

type___ListPlannableProductsResponse = ListPlannableProductsResponse

class ProductMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def plannable_product_code(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def plannable_targeting(self) -> type___PlannableTargeting: ...
    def __init__(
        self,
        *,
        plannable_product_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        plannable_targeting: typing___Optional[type___PlannableTargeting] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "plannable_product_code",
            b"plannable_product_code",
            "plannable_targeting",
            b"plannable_targeting",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "plannable_product_code",
            b"plannable_product_code",
            "plannable_targeting",
            b"plannable_targeting",
        ],
    ) -> None: ...

type___ProductMetadata = ProductMetadata

class PlannableTargeting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    age_ranges: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v3___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue
    ] = ...
    networks: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v3___enums___reach_plan_network_pb2___ReachPlanNetworkEnum.ReachPlanNetworkValue
    ] = ...
    @property
    def genders(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___criteria_pb2___GenderInfo
    ]: ...
    @property
    def devices(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___criteria_pb2___DeviceInfo
    ]: ...
    def __init__(
        self,
        *,
        age_ranges: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue
            ]
        ] = None,
        genders: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___criteria_pb2___GenderInfo
            ]
        ] = None,
        devices: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___criteria_pb2___DeviceInfo
            ]
        ] = None,
        networks: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___enums___reach_plan_network_pb2___ReachPlanNetworkEnum.ReachPlanNetworkValue
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "age_ranges",
            b"age_ranges",
            "devices",
            b"devices",
            "genders",
            b"genders",
            "networks",
            b"networks",
        ],
    ) -> None: ...

type___PlannableTargeting = PlannableTargeting

class GenerateProductMixIdeasRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def plannable_location_id(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def budget_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def preferences(self) -> type___Preferences: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        plannable_location_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        budget_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        preferences: typing___Optional[type___Preferences] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "budget_micros",
            b"budget_micros",
            "currency_code",
            b"currency_code",
            "plannable_location_id",
            b"plannable_location_id",
            "preferences",
            b"preferences",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "budget_micros",
            b"budget_micros",
            "currency_code",
            b"currency_code",
            "customer_id",
            b"customer_id",
            "plannable_location_id",
            b"plannable_location_id",
            "preferences",
            b"preferences",
        ],
    ) -> None: ...

type___GenerateProductMixIdeasRequest = GenerateProductMixIdeasRequest

class Preferences(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ad_length: google___ads___googleads___v3___enums___reach_plan_ad_length_pb2___ReachPlanAdLengthEnum.ReachPlanAdLengthValue = ...
    @property
    def is_skippable(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def starts_with_sound(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def top_content_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def has_guaranteed_price(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        is_skippable: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        starts_with_sound: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        ad_length: typing___Optional[
            google___ads___googleads___v3___enums___reach_plan_ad_length_pb2___ReachPlanAdLengthEnum.ReachPlanAdLengthValue
        ] = None,
        top_content_only: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        has_guaranteed_price: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "has_guaranteed_price",
            b"has_guaranteed_price",
            "is_skippable",
            b"is_skippable",
            "starts_with_sound",
            b"starts_with_sound",
            "top_content_only",
            b"top_content_only",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_length",
            b"ad_length",
            "has_guaranteed_price",
            b"has_guaranteed_price",
            "is_skippable",
            b"is_skippable",
            "starts_with_sound",
            b"starts_with_sound",
            "top_content_only",
            b"top_content_only",
        ],
    ) -> None: ...

type___Preferences = Preferences

class GenerateProductMixIdeasResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def product_allocation(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ProductAllocation
    ]: ...
    def __init__(
        self,
        *,
        product_allocation: typing___Optional[
            typing___Iterable[type___ProductAllocation]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "product_allocation", b"product_allocation"
        ],
    ) -> None: ...

type___GenerateProductMixIdeasResponse = GenerateProductMixIdeasResponse

class ProductAllocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def plannable_product_code(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def budget_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        plannable_product_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        budget_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> None: ...

type___ProductAllocation = ProductAllocation

class GenerateReachForecastRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign_duration(self) -> type___CampaignDuration: ...
    @property
    def cookie_frequency_cap(self) -> google___protobuf___wrappers_pb2___Int32Value: ...
    @property
    def min_effective_frequency(
        self,
    ) -> google___protobuf___wrappers_pb2___Int32Value: ...
    @property
    def targeting(self) -> type___Targeting: ...
    @property
    def planned_products(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PlannedProduct
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign_duration: typing___Optional[type___CampaignDuration] = None,
        cookie_frequency_cap: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
        min_effective_frequency: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
        targeting: typing___Optional[type___Targeting] = None,
        planned_products: typing___Optional[
            typing___Iterable[type___PlannedProduct]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_duration",
            b"campaign_duration",
            "cookie_frequency_cap",
            b"cookie_frequency_cap",
            "currency_code",
            b"currency_code",
            "min_effective_frequency",
            b"min_effective_frequency",
            "targeting",
            b"targeting",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_duration",
            b"campaign_duration",
            "cookie_frequency_cap",
            b"cookie_frequency_cap",
            "currency_code",
            b"currency_code",
            "customer_id",
            b"customer_id",
            "min_effective_frequency",
            b"min_effective_frequency",
            "planned_products",
            b"planned_products",
            "targeting",
            b"targeting",
        ],
    ) -> None: ...

type___GenerateReachForecastRequest = GenerateReachForecastRequest

class Targeting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    age_range: google___ads___googleads___v3___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue = ...
    network: google___ads___googleads___v3___enums___reach_plan_network_pb2___ReachPlanNetworkEnum.ReachPlanNetworkValue = ...
    @property
    def plannable_location_id(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def genders(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___criteria_pb2___GenderInfo
    ]: ...
    @property
    def devices(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___criteria_pb2___DeviceInfo
    ]: ...
    def __init__(
        self,
        *,
        plannable_location_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        age_range: typing___Optional[
            google___ads___googleads___v3___enums___reach_plan_age_range_pb2___ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue
        ] = None,
        genders: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___criteria_pb2___GenderInfo
            ]
        ] = None,
        devices: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___criteria_pb2___DeviceInfo
            ]
        ] = None,
        network: typing___Optional[
            google___ads___googleads___v3___enums___reach_plan_network_pb2___ReachPlanNetworkEnum.ReachPlanNetworkValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "plannable_location_id", b"plannable_location_id"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "age_range",
            b"age_range",
            "devices",
            b"devices",
            "genders",
            b"genders",
            "network",
            b"network",
            "plannable_location_id",
            b"plannable_location_id",
        ],
    ) -> None: ...

type___Targeting = Targeting

class CampaignDuration(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def duration_in_days(self) -> google___protobuf___wrappers_pb2___Int32Value: ...
    def __init__(
        self,
        *,
        duration_in_days: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "duration_in_days", b"duration_in_days"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "duration_in_days", b"duration_in_days"
        ],
    ) -> None: ...

type___CampaignDuration = CampaignDuration

class PlannedProduct(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def plannable_product_code(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def budget_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        plannable_product_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        budget_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> None: ...

type___PlannedProduct = PlannedProduct

class GenerateReachForecastResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def on_target_audience_metrics(self) -> type___OnTargetAudienceMetrics: ...
    @property
    def reach_curve(self) -> type___ReachCurve: ...
    def __init__(
        self,
        *,
        on_target_audience_metrics: typing___Optional[
            type___OnTargetAudienceMetrics
        ] = None,
        reach_curve: typing___Optional[type___ReachCurve] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "on_target_audience_metrics",
            b"on_target_audience_metrics",
            "reach_curve",
            b"reach_curve",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "on_target_audience_metrics",
            b"on_target_audience_metrics",
            "reach_curve",
            b"reach_curve",
        ],
    ) -> None: ...

type___GenerateReachForecastResponse = GenerateReachForecastResponse

class ReachCurve(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def reach_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ReachForecast
    ]: ...
    def __init__(
        self,
        *,
        reach_forecasts: typing___Optional[
            typing___Iterable[type___ReachForecast]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["reach_forecasts", b"reach_forecasts"],
    ) -> None: ...

type___ReachCurve = ReachCurve

class ReachForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def forecast(self) -> type___Forecast: ...
    @property
    def forecasted_product_allocations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ProductAllocation
    ]: ...
    def __init__(
        self,
        *,
        cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        forecast: typing___Optional[type___Forecast] = None,
        forecasted_product_allocations: typing___Optional[
            typing___Iterable[type___ProductAllocation]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "cost_micros", b"cost_micros", "forecast", b"forecast"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "cost_micros",
            b"cost_micros",
            "forecast",
            b"forecast",
            "forecasted_product_allocations",
            b"forecasted_product_allocations",
        ],
    ) -> None: ...

type___ReachForecast = ReachForecast

class Forecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def on_target_reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def total_reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def on_target_impressions(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def total_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        on_target_reach: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        total_reach: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        on_target_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        total_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "on_target_impressions",
            b"on_target_impressions",
            "on_target_reach",
            b"on_target_reach",
            "total_impressions",
            b"total_impressions",
            "total_reach",
            b"total_reach",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "on_target_impressions",
            b"on_target_impressions",
            "on_target_reach",
            b"on_target_reach",
            "total_impressions",
            b"total_impressions",
            "total_reach",
            b"total_reach",
        ],
    ) -> None: ...

type___Forecast = Forecast

class OnTargetAudienceMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def youtube_audience_size(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def census_audience_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        youtube_audience_size: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        census_audience_size: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "census_audience_size",
            b"census_audience_size",
            "youtube_audience_size",
            b"youtube_audience_size",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "census_audience_size",
            b"census_audience_size",
            "youtube_audience_size",
            b"youtube_audience_size",
        ],
    ) -> None: ...

type___OnTargetAudienceMetrics = OnTargetAudienceMetrics
